import './index.css';

// src/benchmark/ProgressBar.tsx
import { motion } from "framer-motion";
import { useState } from "react";

// src/benchmark/ProgressBar.module.scss
var ProgressBar_module_default = { "container": "container_72b36", "innerContainer": "innerContainer_72b36", "bar": "bar_72b36", "desc": "desc_72b36", "time": "time_72b36" };

// src/benchmark/ProgressBar.tsx
import { jsx, jsxs } from "react/jsx-runtime";
function formatTime(time, totalTime) {
  if (totalTime < 1e3) {
    return `${time.toFixed(0)}ms`;
  }
  return `${(time / 1e3).toFixed(2)}s`;
}
function ProgressBar({
  value,
  max,
  desc,
  inView
}) {
  const [elapsedTime, setElapsedTime] = useState(0);
  const TOTAL_TIME = value * 1e3;
  const variants = {
    initial: { width: 0 },
    animate: { width: `${value / max * 100}%` }
  };
  const formattedTime = formatTime(elapsedTime, TOTAL_TIME);
  return /* @__PURE__ */ jsxs("div", { className: ProgressBar_module_default.container, children: [
    /* @__PURE__ */ jsx("div", { className: ProgressBar_module_default.innerContainer, children: inView ? /* @__PURE__ */ jsx(
      motion.div,
      {
        className: ProgressBar_module_default.bar,
        initial: "initial",
        animate: "animate",
        variants,
        onUpdate: (latest) => {
          const width = Number.parseFloat(latest.width);
          setElapsedTime(width * max * 10);
        },
        transition: { duration: value, ease: "linear" }
      }
    ) : null }),
    /* @__PURE__ */ jsxs("div", { className: ProgressBar_module_default.desc, children: [
      /* @__PURE__ */ jsx("span", { className: ProgressBar_module_default.time, children: formattedTime }),
      " ",
      desc
    ] })
  ] });
}

// src/benchmark/index.module.scss
var index_module_default = { "root": "root_bcdcd", "title": "title_bcdcd", "desc": "desc_bcdcd", "bottomLink": "bottomLink_bcdcd", "progressName": "progressName_bcdcd", "item": "item_bcdcd" };

// node_modules/.pnpm/react-intersection-observer@9.13.0_react-dom@18.3.1_react@18.3.1__react@18.3.1/node_modules/react-intersection-observer/dist/index.mjs
import * as React from "react";
import * as React2 from "react";
var observerMap = /* @__PURE__ */ new Map();
var RootIds = /* @__PURE__ */ new WeakMap();
var rootId = 0;
var unsupportedValue = void 0;
function getRootId(root) {
  if (!root)
    return "0";
  if (RootIds.has(root))
    return RootIds.get(root);
  rootId += 1;
  RootIds.set(root, rootId.toString());
  return RootIds.get(root);
}
function optionsToId(options) {
  return Object.keys(options).sort().filter(
    (key) => options[key] !== void 0
  ).map((key) => {
    return `${key}_${key === "root" ? getRootId(options.root) : options[key]}`;
  }).toString();
}
function createObserver(options) {
  const id = optionsToId(options);
  let instance = observerMap.get(id);
  if (!instance) {
    const elements = /* @__PURE__ */ new Map();
    let thresholds;
    const observer = new IntersectionObserver((entries) => {
      entries.forEach((entry) => {
        var _a;
        const inView = entry.isIntersecting && thresholds.some((threshold) => entry.intersectionRatio >= threshold);
        if (options.trackVisibility && typeof entry.isVisible === "undefined") {
          entry.isVisible = inView;
        }
        (_a = elements.get(entry.target)) == null ? void 0 : _a.forEach((callback) => {
          callback(inView, entry);
        });
      });
    }, options);
    thresholds = observer.thresholds || (Array.isArray(options.threshold) ? options.threshold : [options.threshold || 0]);
    instance = {
      id,
      observer,
      elements
    };
    observerMap.set(id, instance);
  }
  return instance;
}
function observe(element, callback, options = {}, fallbackInView = unsupportedValue) {
  if (typeof window.IntersectionObserver === "undefined" && fallbackInView !== void 0) {
    const bounds = element.getBoundingClientRect();
    callback(fallbackInView, {
      isIntersecting: fallbackInView,
      target: element,
      intersectionRatio: typeof options.threshold === "number" ? options.threshold : 0,
      time: 0,
      boundingClientRect: bounds,
      intersectionRect: bounds,
      rootBounds: bounds
    });
    return () => {
    };
  }
  const { id, observer, elements } = createObserver(options);
  const callbacks = elements.get(element) || [];
  if (!elements.has(element)) {
    elements.set(element, callbacks);
  }
  callbacks.push(callback);
  observer.observe(element);
  return function unobserve() {
    callbacks.splice(callbacks.indexOf(callback), 1);
    if (callbacks.length === 0) {
      elements.delete(element);
      observer.unobserve(element);
    }
    if (elements.size === 0) {
      observer.disconnect();
      observerMap.delete(id);
    }
  };
}
function useInView({
  threshold,
  delay,
  trackVisibility,
  rootMargin,
  root,
  triggerOnce,
  skip,
  initialInView,
  fallbackInView,
  onChange
} = {}) {
  var _a;
  const [ref, setRef] = React2.useState(null);
  const callback = React2.useRef();
  const [state, setState] = React2.useState({
    inView: !!initialInView,
    entry: void 0
  });
  callback.current = onChange;
  React2.useEffect(
    () => {
      if (skip || !ref)
        return;
      let unobserve;
      unobserve = observe(
        ref,
        (inView, entry) => {
          setState({
            inView,
            entry
          });
          if (callback.current)
            callback.current(inView, entry);
          if (entry.isIntersecting && triggerOnce && unobserve) {
            unobserve();
            unobserve = void 0;
          }
        },
        {
          root,
          rootMargin,
          threshold,
          // @ts-ignore
          trackVisibility,
          // @ts-ignore
          delay
        },
        fallbackInView
      );
      return () => {
        if (unobserve) {
          unobserve();
        }
      };
    },
    // We break the rule here, because we aren't including the actual `threshold` variable
    // eslint-disable-next-line react-hooks/exhaustive-deps
    [
      // If the threshold is an array, convert it to a string, so it won't change between renders.
      Array.isArray(threshold) ? threshold.toString() : threshold,
      ref,
      root,
      rootMargin,
      triggerOnce,
      skip,
      trackVisibility,
      fallbackInView,
      delay
    ]
  );
  const entryTarget = (_a = state.entry) == null ? void 0 : _a.target;
  const previousEntryTarget = React2.useRef();
  if (!ref && entryTarget && !triggerOnce && !skip && previousEntryTarget.current !== entryTarget) {
    previousEntryTarget.current = entryTarget;
    setState({
      inView: !!initialInView,
      entry: void 0
    });
  }
  const result = [setRef, state.inView, state.entry];
  result.ref = result[0];
  result.inView = result[1];
  result.entry = result[2];
  return result;
}

// src/benchmark/index.tsx
import { jsx as jsx2, jsxs as jsxs2 } from "react/jsx-runtime";
var findMaxTime = (data) => {
  let max = 0;
  for (const item of Object.values(data)) {
    for (const metric of item.metrics) {
      if (metric.time > max) {
        max = metric.time;
      }
    }
  }
  return max;
};
function Benchmark({ data }) {
  const maxTime = findMaxTime(data);
  const { ref, inView } = useInView({
    triggerOnce: true
  });
  return /* @__PURE__ */ jsx2("div", { className: index_module_default.root, ref, children: Object.values(data).map((item) => /* @__PURE__ */ jsxs2("div", { className: index_module_default.item, children: [
    /* @__PURE__ */ jsx2("p", { className: index_module_default.progressName, children: item.label }),
    /* @__PURE__ */ jsx2("div", { children: item.metrics.map((metric) => /* @__PURE__ */ jsx2(
      ProgressBar,
      {
        value: metric.time,
        max: maxTime,
        desc: metric.desc,
        inView
      },
      metric.desc
    )) })
  ] }, item.label)) });
}
export {
  Benchmark
};
